pub enum InferShapesError {
IncorrectInputCount,
IncompatibleShapes,
IncorrectRank,
InvalidValue,
UnknownOutputCount,
}Expand description
Errors when performing shape inference.
Variants
IncorrectInputCount
Too many or too few inputs were provided for this operator.
IncompatibleShapes
The input shapes are incompatible.
Operator execution will fail if given inputs with these shapes.
IncorrectRank
An input’s rank does not match that expected by the operator.
InvalidValue
An operator input or attribute has an invalid value.
UnknownOutputCount
The number of outputs could not be determined.