SymExpr

Enum SymExpr 

pub enum SymExpr {
    Value(i32),
    Var(Rc<Symbol>),
    Add((Rc<SymExpr>, Rc<SymExpr>)),
    Sub((Rc<SymExpr>, Rc<SymExpr>)),
    Mul((Rc<SymExpr>, Rc<SymExpr>)),
    Div((Rc<SymExpr>, Rc<SymExpr>)),
    DivCeil((Rc<SymExpr>, Rc<SymExpr>)),
    Max((Rc<SymExpr>, Rc<SymExpr>)),
    Min((Rc<SymExpr>, Rc<SymExpr>)),
    Broadcast((Rc<SymExpr>, Rc<SymExpr>)),
    Neg(Rc<SymExpr>),
}
Symbolic expression representing an integer value.

Expressions can be known integer values, named symbols or composite expressions.

Variants



Value(i32)

Element with a known integer value.



Var(Rc<Symbol>)

Symbolic value



Add((Rc<SymExpr>, Rc<SymExpr>))

Addition of two symbolic values



Sub((Rc<SymExpr>, Rc<SymExpr>))

Subtraction of two symbolic values



Mul((Rc<SymExpr>, Rc<SymExpr>))

Multiplication of two symbolic values



Div((Rc<SymExpr>, Rc<SymExpr>))

Flooring division of first expression by second.



DivCeil((Rc<SymExpr>, Rc<SymExpr>))

Ceiling division of first expression by second.



Max((Rc<SymExpr>, Rc<SymExpr>))

Maximum of two symbolic values



Min((Rc<SymExpr>, Rc<SymExpr>))

Minimum of two symbolic values



Broadcast((Rc<SymExpr>, Rc<SymExpr>))

Broadcast two symbolic values.

This behaves like Max, except it implies that both expressions are positive and either equal or 1.



Neg(Rc<SymExpr>)

Negation of a value

Implementations

Source

impl SymExpr

pub fn range(&self) -> (i32, i32)

Return the range of possible values this element may have.

pub fn is_positive(&self) -> bool

Return true if the value of this expression is known to be >= 0.

pub fn max(&self, other: &SymExpr) -> SymExpr

Return the maximum of self and other.

pub fn min(&self, other: &SymExpr) -> SymExpr

Return the minimum of self and other.

pub fn broadcast(&self, other: &SymExpr) -> SymExpr

Return the result of broadcasting self and other.

pub fn div_ceil(&self, other: &SymExpr) -> SymExpr

Return the result of dividing self by other, rounded up.

pub fn simplify(&self) -> SymExpr

Simplify an expression.

This simplifies expressions such as identities (eg. x + 0 becomes x).

pub fn var(name: &str) -> Self

Create a named symbol, with no assumptions about the value.

pub fn pos_var(name: &str) -> Self

Create a named symbol representing a positive value (ie. >= 0).

pub fn exact_div(&self, rhs: &SymExpr) -> Option<SymExpr>

Compute self / rhs as an expression, or return None if an exact division is not possible.