pub struct BinaryOp;Expand description
Shape inference for binary operators.
These operators take two inputs and return an output whose shape is the result of broadcasting the two input shapes together following ONNX’s broadcasting rules.