pub struct ReductionOp<'a> {
pub axes: Option<&'a [i32]>,
pub keep_dims: bool,
}Expand description
Shape inference for reduction operators.
Fields
axes: Option<&'a [i32]>Axes over which the reduction is applied.
Reduction ops take the axes as an attribute in ONNX opset <= 13 and an input in opset 18+.
keep_dims: boolTrue if the reduced dimension is retained as a 1-sized dimension in the output.