pub struct Symbol {
pub name: String,
pub positive: bool,
}Expand description
A named variable.
The variable may carry assumptions about its value, such as being >= 0.
Two symbols are equal if they have the same name.
Fields
name: Stringpositive: boolTrait Implementations
impl StructuralPartialEq for Symbol