SymbolGen

Struct SymbolGen 

pub struct SymbolGen { /* private fields */ }
Generates named symbols.

Sometimes during shape inference it may be necessary to generate a new symbol to represent a value that cannot be represented as an expression.

Note that generally it is preferred to represent values computed from other values as symbolic expressions. This allows the expressions to be compared, simplified and otherwise manipulated.

Implementations

Source

impl SymbolGen

pub fn new() -> Self

pub fn with_prefix(prefix: Cow<'static, str>) -> Self

pub fn gen_positive(&mut self) -> SymExpr

Generate a new symbolic value which is assumed to be positive.