pub struct SymbolGen { /* private fields */ }Expand description
Generates named symbols.
Sometimes during shape inference it may be necessary to generate a new symbol to represent a value that cannot be represented as an expression.
Note that generally it is preferred to represent values computed from other values as symbolic expressions. This allows the expressions to be compared, simplified and otherwise manipulated.
Implementations